@@ -567,7 +567,7 @@ def colorTest(limit=256):
     for i in range(1,limit):
         retColorStr+=','+str(len(str(i))+1)+'|'+str(i)
         retStr+=str(i)+' '
-    consoleOut('color',retStr,'SPACE',colorStr=retColorStr,COLORFLITER=False)
+    consoleOut('color',retStr,'SPACE',colorStr=retColorStr,COLORFILTER=False)
 def followSay(word,fColor=_white):
     say(__OUTX__,__OUTY__,word,fColor)
 def echo(content,color=_white,STDOUT='$n0p'):
